/**
 * Configured package sources.
 */
export interface PackageSources {
    /**
     * Get the package source with the specified name.
     *
     * @param packageSourceName The package source name.
     * @returns The package source URL or file-system path.
     */
    [packageSourceName: string]: string;
}
/**
 * Get configured package sources from NuGet.config.
 *
 * @param nugetConfigPath The path to NuGet.config.
 */
export declare function getConfiguredPackageSources(nugetConfigPath: string): Promise<PackageSources>;
/**
 * Get the full path to the user-level NuGet.config file.
 *
 * @returns {Promise<string | null>} A promise that resolves to NuGet.config, or null if the file does not exist.
 */
export declare function getUserNuGetConfigFile(): Promise<string | null>;
